
var SVG_NS ="http://www.w3.org/2000/svg";
var XLINK_NS = "http://www.w3.org/1999/xlink";

var togglePlayMode = "play";

function distinctColorHSL(sn,numSegs) {

    var Hangle = 360 * sn / numSegs;
    var Sperc  = 10 + 90 * sn / numSegs;
    var Vperc  = 40 + 60 * sn / numSegs;

    return 'hsl(' + Hangle + ', ' + Sperc + '%, ' + Vperc + '%)';

}


function togglePlayVisual(elem)
{
    if (togglePlayMode.match("play")) {
	// switch to displaying pause
	elem.src="ext/audioDB/icons/pause32.png";
	togglePlayMode = "pause";
    }
    else {
	elem.src="ext/audioDB/icons/play32.png";
	togglePlayMode = "play";
    }
}

function togglePlay(event,elem)
{
    togglePlayVisual(elem);

    if (event != null) {
	event.stopPropagation();
	event.preventDefault();
    }

    // switching to offering pause (means it was a play button when clicked)
    if (togglePlayMode.match("pause")) {
	if (playTrackerMode.match("paused")) {
	    rightSong.play();
	    leftSong.play();
	    pannedPlayback.play();
	    playTrackerMode = "playing";
	}
	else {
	    var currentPosElem = document.getElementById("mysongCurrentPos");
	    var offsetInMSecs = currentPosElem.getAttribute("offsetInMSecs");
	    // console.log("offsetInMSecs = " + offsetInMSecs);

	    if (offsetInMSecs==null) { offsetInMSecs = 0; }
	    var frameOffset = Math.round(offsetInMSecs/250.0);
	    playFromOffset("mysong",frameOffset);
	}
    }
    else {
	// figure out if mysong or dualPlay in operatio, and pause it

	if (playTrackerMode.match("playing")) {
	    pannedPlayback.pause();
	    leftSong.pause();
	    rightSong.pause();

	    playTrackerMode = "paused";
	}
	else {
	    soundManager.pause("mysong");
	}
    }
}



function playHighlightOn(elem,size)
{
    size = (size) ? size : 32;
 
    if (togglePlayMode.match("play")) {
	elem.setAttribute("src","ext/audioDB/icons/play"+size+"Highlight.png");
    }
    else {
	elem.setAttribute("src","ext/audioDB/icons/pause"+size+"Highlight.png");
    }
}

function playHighlightOff(elem,size)
{
    size = (size) ? size : 32;

    if (togglePlayMode.match("play")) {
	elem.setAttribute("src","ext/audioDB/icons/play"+size+".png");
    }
    else {
	elem.setAttribute("src","ext/audioDB/icons/pause"+size+".png");
    }
}

function playHighlightOnSVG(elem,size)
{
    size = (size) ? size : 32;
 
    elem.setAttributeNS(XLINK_NS,"xlink:href","ext/audioDB/icons/play"+size+"Highlight.png");
}

function playHighlightOffSVG(elem,size)
{
    size = (size) ? size : 32;

    elem.setAttributeNS(XLINK_NS,"xlink:href","ext/audioDB/icons/play"+size+".png");

}


function searchHighlightOnSVG(elem,size)
{
    size = (size) ? size : 32;
 
    elem.setAttributeNS(XLINK_NS,"xlink:href","ext/audioDB/icons/search"+size+"Highlight.png");
}

function searchHighlightOffSVG(elem,size)
{
    size = (size) ? size : 32;

    elem.setAttributeNS(XLINK_NS,"xlink:href","ext/audioDB/icons/search"+size+".png");

}


function raiseSPRect(elem)
{
    elem.setAttribute("style","z-index: 5;");
}


function lowerSPRect(elem)
{
    elem.setAttribute("style","");
}

function renderStructuredSegBar(segsElem, segData) 
{
    var mysong   = document.getElementById("mysong");
    var barWidth = mysong.getElementWidth();

    // Count how many different labels we have 

    var segFreq = {};
    var numLabels = 0;

    for(var i=0; i< segData.length; i++) {
        var value = segData[i].l;
        if(value in segFreq) {
            segFreq[value]++;
        }
        else {
            segFreq[value] = 1;
	    numLabels++;
        }
    }

    var numSegs = segData.length;

    for (i=0; i < numSegs; i++) {

	var offsetInSecs = segData[i].o;
	var frameOffset = Math.round(offsetInSecs*1000/250.0);

	var label = segData[i].l;
	var labelOrd = label.charCodeAt(0);
	var letterBaseOrd = "A".charCodeAt(0);
	var numberBaseOrd = "0".charCodeAt(0);

	var baseOrd;
	if ((labelOrd >= numberBaseOrd) && (labelOrd <= "9".charCodeAt(0))) {
	    baseOrd = numberBaseOrd;
	}
	else {
	    baseOrd = letterBaseOrd;
	}

	var labelIndex = label.charCodeAt(0) - baseOrd;
	var labelColor = distinctColorHSL(labelIndex,numLabels);

	var x = barWidth * offsetInSecs / duration;
	var y = 0;

	var nextOffsetInSecs 
	    = (i < numSegs-1) ? segData[i+1].o : duration;
	var nextX = barWidth * nextOffsetInSecs / duration;

	var gElem = document.createElementNS(SVG_NS,'g');
	gElem.setAttribute('transform','translate('+x+','+y+')');
	gElem.setAttribute("onmouseover","raiseSPRect(evt.target)");
	gElem.setAttribute("onmouseout","lowerSPRect(evt.target)");

	var rectElem = document.createElementNS(SVG_NS,'rect');
	rectElem.setAttribute('width',nextX - x - 1);
	rectElem.setAttribute('height','24');
	rectElem.setAttribute('x','0');
	rectElem.setAttribute('y','0');
	/* rectElem.setAttribute('stroke-width', '5'); */
	rectElem.setAttribute('fill', labelColor);


	var textElem = document.createElementNS(SVG_NS,'text');
	textElem.setAttribute('x','5');
	textElem.setAttribute('y','18');

	var textNode = document.createTextNode(label);
	textElem.appendChild(textNode);

	var playImgElem = document.createElementNS(SVG_NS,"image");
	playImgElem.setAttributeNS(XLINK_NS, "xlink:href", 
				   "ext/audioDB/icons/play20.png");
	playImgElem.setAttribute("x","20");
	playImgElem.setAttribute("y","2");
	playImgElem.setAttribute("width","20");
	playImgElem.setAttribute("height","20");

	var onclick ="playFromOffset('mysong'," + frameOffset + ")";
	playImgElem.setAttribute("onclick",onclick);

	playImgElem.setAttribute("onmouseover","playHighlightOnSVG(evt.target,20)");
	playImgElem.setAttribute("onmouseout", "playHighlightOffSVG(evt.target,20)");


	var searchImgElem = document.createElementNS(SVG_NS,'image');
	searchImgElem.setAttributeNS(XLINK_NS, "xlink:href", 
				     "ext/audioDB/icons/search20.png");
	searchImgElem.setAttribute("x","44");
	searchImgElem.setAttribute("y","2");
	searchImgElem.setAttribute("width","20");
	searchImgElem.setAttribute("height","20");
	var onclickSearch ="searchSubmit("+frameOffset+")";
	searchImgElem.setAttribute("onclick",onclickSearch);

	searchImgElem.setAttribute("onmouseover","searchHighlightOnSVG(evt.target,20)");
	searchImgElem.setAttribute("onmouseout", "searchHighlightOffSVG(evt.target,20)");

	gElem.appendChild(rectElem);
	gElem.appendChild(textElem);
	gElem.appendChild(playImgElem);
	gElem.appendChild(searchImgElem);
	segsElem.appendChild(gElem);

    }
}


function svgGTStructuredInit() 
{
    var segDataGT = allData[0]; /* pick out ground truth data */    
    var segsElemGT = document.getElementById("svgGroundTruthSegments");

    renderStructuredSegBar(segsElemGT,segDataGT);
}

function svgCAStructuredInit(caPos) 
{
    var segsElemCA = document.getElementById("svgContentAnalysisSegments");

    
    if (caPos == -1) {
	ssegsElemCA.setAttribute("style","display: none;");
    }
    else {
	var segDataCA = allData[caPos]; /* pick out example content analysis data */ 

	renderStructuredSegBar(segsElemCA,segDataCA);
	//ssegsElemCA.setAttribute("style","display: block;");

    }
}
